// Settings
#include "/libs/settings.glsl"

// Uniforms
#include "/libs/uniforms.glsl"

// Inputs
in vec2 texCoord;

// Outputs
/* RENDERTARGETS: 0 */
layout(location = 0) out vec4 color;

// Functions
#include "/libs/functions.glsl"

bool Edge(){
    vec3 normal = texture(colortex1, texCoord).xyz * 2.0 - 1.0;
    vec3 originPos = screenToView(texCoord, texture(depthtex0, texCoord).x);
    originPos = viewToFeetPlayer(originPos);

    float result = -1.0;

    for(int x = -1; x <= 1; x++){
        for(int y = -1; y <= 1; y++){
            vec2 offset = vec2(x, y) * texelSize;
            vec3 offsetPos = screenToView(texCoord + offset, texture(depthtex0, texCoord + offset).x);
            offsetPos = viewToFeetPlayer(offsetPos);
            vec3 diff = offsetPos - originPos;
            float a = abs(dot(normal, normalize(diff)));
            result = max(result, a);
        }
    }

    float dist = length(originPos) / far;
    float threshold = exp((dist - 1.0) * 2.0);

    return result > threshold ? true : false;
}

// Main
void main(){
    color = texture(colortex0, texCoord);

    if(EDGE_EFFECTS){
        if(EDGE_TYPE == 1) color.rgb = texture(colortex1, texCoord).rgb * 2.0 - 1.0;
        else if(EDGE_TYPE == 2) color.rgb = vec3(1.0);
        else if(EDGE_TYPE == 3) color.rgb = vec3(0.0);
        if(Edge()){
            color.rgb = vec3(EDGE_COLOR_R, EDGE_COLOR_G, EDGE_COLOR_B);
        }
    }
}